@@ -1,12 +1,14 @@
 package Form::Factory::Feature::Control::MatchRegex;
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 
 use Moose;
 
 with qw( 
     Form::Factory::Feature 
+    Form::Factory::Feature::Role::Check
     Form::Factory::Feature::Role::Control
+    Form::Factory::Feature::Role::CustomControlMessage
 );
 
 =head1 NAME
@@ -15,7 +17,7 @@ Form::Factory::Feature::Control::MatchRegex - Match a control value against a re
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -63,13 +65,13 @@ sub check_control {
     die "the match_regex feature only works with scalar value controls, not $control";
 }
 
-=head2 check_value
+=head2 check
 
 Runs the regular expression against the current value of the control and reports an error if it does not match.
 
 =cut
 
-sub check_value {
+sub check {
     my $self  = shift;
     my $value = $self->control->current_value;
 
